﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Warship
{
    public class DrawingWarship
    {
        public EntityWarship Warship { get; protected set; }
        protected int _startPosX;
        protected int _startPosY;
        private int? _pictureWidth = null;
        private int? _pictureHeight = null;
        private readonly int _warshipWidth = 120;
        private readonly int _warshipHeight = 40;

        public DrawingWarship(int speed, float weight, Color bodyColor)
        {
            Warship=new EntityWarship(speed, weight, bodyColor);
        }

        protected DrawingWarship(int speed, float weight,Color bodyColor, int warshipWidth, int warshipHeight) : this(speed,weight,bodyColor)
        {
            _warshipWidth = warshipWidth;
            _warshipHeight = warshipHeight;
        }


        public void SetPosition(int x, int y, int width, int height)
        {
            if (x >= 0 && x+_warshipWidth <= width && y >= 0 && y+_warshipHeight <= height)
            {
                _startPosX = x;
                _startPosY = y;
                _pictureWidth = width;
                _pictureHeight = height;
            }
            else return;
        }

        public void MoveTransport(Direction direction)
        {
            if (!_pictureWidth.HasValue || !_pictureHeight.HasValue)
            {
                return;
            }
            switch (direction)
            {
                case Direction.Right:
                    if (_startPosX + _warshipWidth + Warship.Step < _pictureWidth)
                    {
                        _startPosX+=Warship.Step;
                    }
                    break;

                case Direction.Left:
                    if (_startPosX- Warship.Step >= 0)
                    {
                        _startPosX -= Warship.Step;
                    }
                    break;

                case Direction.Up:
                    if (_startPosY - Warship.Step >= 0)
                    {
                        _startPosY -= Warship.Step;
                    }
                    break;

                case Direction.Down:
                    if (_startPosY + _warshipHeight + Warship.Step < _pictureHeight)
                    {
                        _startPosY += Warship.Step;
                    }
                    break;
            }
        }

        public virtual void DrawTransport(Graphics g)
        {
            if (_startPosX < 0 || _startPosY < 0 || !_pictureHeight.HasValue || !_pictureWidth.HasValue)
            {
                return;
            }

            SolidBrush Corp = new SolidBrush(Warship?.BodyColor ?? Color.Black);

            g.FillPolygon(Corp, new Point[]
            {
                new Point(_startPosX+5,_startPosY),new Point(_startPosX+80,_startPosY),
                new Point(_startPosX+120,_startPosY+20),new Point(_startPosX+80,_startPosY+40),
                new Point(_startPosX+5,_startPosY+40),new Point(_startPosX+5,_startPosY)
            }
            );

            Pen pen = new Pen(Color.Black,2);

            g.DrawLine(pen, new Point(_startPosX + 5, _startPosY), new Point(_startPosX + 80, _startPosY));
            g.DrawLine(pen, new Point(_startPosX + 80, _startPosY), new Point(_startPosX + 120, _startPosY + 20));
            g.DrawLine(pen, new Point(_startPosX + 120, _startPosY + 20), new Point(_startPosX + 80, _startPosY + 40));
            g.DrawLine(pen, new Point(_startPosX + 80, _startPosY + 40), new Point(_startPosX + 5, _startPosY + 40));
            g.DrawLine(pen, new Point(_startPosX + 5, _startPosY + 40), new Point(_startPosX + 5, _startPosY));

            SolidBrush Motor = new SolidBrush(Color.Black);

            g.FillRectangle(Motor, _startPosX, _startPosY + 5, 5, 10);
            g.FillRectangle(Motor, _startPosX, _startPosY + 25, 5, 10);

            SolidBrush Yash = new SolidBrush(Color.Brown);

            g.DrawRectangle(pen, _startPosX + 30, _startPosY + 15, 20, 10);
            g.FillRectangle(Yash, _startPosX+30, _startPosY + 15, 20, 10);
            g.DrawRectangle(pen, _startPosX + 50, _startPosY + 10, 10, 20);
            g.FillRectangle(Yash, _startPosX + 50, _startPosY + 10, 10, 20);

            SolidBrush Win = new SolidBrush(Color.Blue);

            g.DrawEllipse(pen, _startPosX + 70, _startPosY + 15, 10, 10);
            g.FillEllipse(Win, _startPosX + 70, _startPosY + 15, 10, 10);
        }

        public void ChangeBorders(int width,int height)
        {
            _pictureWidth = width;
            _pictureHeight = height;
            if (_pictureWidth<=_warshipWidth||_pictureHeight<=_warshipHeight)
            {
                _pictureWidth = null;
                _pictureHeight = null;
                return;
            }
            if (_startPosX + _warshipWidth > _pictureWidth)
            {
                _startPosX = _pictureWidth.Value - _warshipWidth;
            }
            if (_startPosY + _warshipHeight > _pictureHeight)
            {
                _startPosY = _pictureHeight.Value - _warshipHeight;
            }
        }
        public (float Left, float Right, float Top, float Bottom) GetCurrentPosition()
        {
            return (_startPosX, _startPosY, _startPosX + _warshipWidth, _startPosY + _warshipHeight);
        }
    }
}
