﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Warship
{
    public partial class FormMapWithSetWarships : Form
    {
        private MapWithSetWarshipsGeneric<DrawingObjectWarship, AbstractMap> _mapWarshipsCollectionGeneric;

        public FormMapWithSetWarships()
        {
            InitializeComponent();
        }

        private void ComboBoxSelectorMap_SelectedIndexChanged(object sender, EventArgs e)
        {
            AbstractMap map = null;
            switch (comboBoxSelectorMap.Text)
            {
                case "Простая карта":
                    map = new SimpleMap();
                    break;
            }
            if (map != null)
            {
                _mapWarshipsCollectionGeneric = new MapWithSetWarshipsGeneric<DrawingObjectWarship, AbstractMap>(
                pictureBox.Width, pictureBox.Height, map);
            }
            else
            {
                _mapWarshipsCollectionGeneric = null;
            }
        }

        private void ButtonAddWarship_Click(object sender, EventArgs e)
        {
            if (_mapWarshipsCollectionGeneric == null)
            {
                return;
            }
            FormWarship form = new();
            if (form.ShowDialog() == DialogResult.OK)
            {
                DrawingObjectWarship warship = new(form.SelectedWarship);
                if (_mapWarshipsCollectionGeneric + warship)
                {
                    MessageBox.Show("Объект добавлен");
                    pictureBox.Image = _mapWarshipsCollectionGeneric.ShowSet();
                }
                else
                {
                    MessageBox.Show("Не удалось добавить объект");
                }
            }
        }

        private void ButtonRemoveWarship_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(maskedTextBoxPosition.Text))
            {
                return;
            }
            if (MessageBox.Show("Удалить объект?", "Удаление", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
            {
                return;
            }
            int pos = Convert.ToInt32(maskedTextBoxPosition.Text);
            if (_mapWarshipsCollectionGeneric - pos)
            {
                MessageBox.Show("Объект удален");
                pictureBox.Image = _mapWarshipsCollectionGeneric.ShowSet();
            }
            else
            {
                MessageBox.Show("Не удалось удалить объект");
            }
        }

        private void ButtonShowStorage_Click(object sender, EventArgs e)
        {
            if (_mapWarshipsCollectionGeneric == null)
            {
                return;
            }
            pictureBox.Image = _mapWarshipsCollectionGeneric.ShowSet();
        }

        private void ButtonShowOnMap_Click(object sender, EventArgs e)
        {
            if (_mapWarshipsCollectionGeneric == null)
            {
                return;
            }
            pictureBox.Image = _mapWarshipsCollectionGeneric.ShowOnMap();
        }

        private void ButtonMove_Click(object sender, EventArgs e)
        {
            if (_mapWarshipsCollectionGeneric == null)
            {
                return;
            }
            string name = ((Button)sender)?.Name ?? string.Empty;
            Direction dir = Direction.None;
            switch (name)
            {
                case "buttonUp":
                    dir = Direction.Up;
                    break;
                case "buttonDown":
                    dir = Direction.Down;
                    break;
                case "buttonLeft":
                    dir = Direction.Left;
                    break;
                case "buttonRight":
                    dir = Direction.Right;
                    break;
            }
            pictureBox.Image = _mapWarshipsCollectionGeneric.MoveObject(dir);
        }
    }
}
